==> bridge_1.4.0.zip: bridge/doc/bridge.R <==
###################################################
### chunk number 1: 
###################################################
library(bridge)


###################################################
### chunk number 2: 
###################################################
data(hiv)


###################################################
### chunk number 3: 
###################################################
bridge.hiv<-bridge.2samples(hiv[1:640,c(1:4)],hiv[1:640,c(5:8)],B=2000,min.iter=0,batch=1,mcmc.obj=NULL,affy=FALSE,verbose=FALSE)


###################################################
### chunk number 4: 
###################################################
gamma1<-mat.mean(bridge.hiv$gamma1)[,1]
gamma2<-mat.mean(bridge.hiv$gamma2)[,1]


###################################################
### chunk number 5: logratio
###################################################
plot(gamma1-gamma2,bridge.hiv$post.p,col=1,pch=1,main="Posterior probability",xlab="log ratio",ylab="posterior probability")


###################################################
### chunk number 6: histdf
###################################################
hist(bridge.hiv$nu1[3,],main="Posterior degree of freedoms, array 3",xlab="nu",50)


###################################################
### chunk number 7: 
###################################################
sample1<-matrix(exp(rnorm(150)),50,3)
sample2<-matrix(exp(rnorm(200)),50,4)
sample3<-matrix(exp(rnorm(150)),50,3)

mcmc.bridge3<-bridge.3samples(sample1,sample2,sample3,B=10,min.iter=0,batch=1,mcmc.obj=NULL,all.out=TRUE,verbose=FALSE)

==> bridge_1.14.0.zip: bridge/doc/bridge.R <==
###################################################
### chunk number 1: 
###################################################
#line 85 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp7loolu/R.INSTALL3bc220a5/bridge/inst/doc/bridge.Rnw"
library(bridge)


###################################################
### chunk number 2: 
###################################################
#line 132 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp7loolu/R.INSTALL3bc220a5/bridge/inst/doc/bridge.Rnw"
data(hiv)


###################################################
### chunk number 3: 
###################################################
#line 154 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp7loolu/R.INSTALL3bc220a5/bridge/inst/doc/bridge.Rnw"
bridge.hiv<-bridge.2samples(hiv[1:640,c(1:4)],hiv[1:640,c(5:8)],B=2000,min.iter=0,batch=1,mcmc.obj=NULL,affy=FALSE,verbose=FALSE)


###################################################
### chunk number 4: 
###################################################
#line 159 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp7loolu/R.INSTALL3bc220a5/bridge/inst/doc/bridge.Rnw"
gamma1<-mat.mean(bridge.hiv$gamma1)[,1]
gamma2<-mat.mean(bridge.hiv$gamma2)[,1]


###################################################
### chunk number 5: logratio
###################################################
#line 165 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp7loolu/R.INSTALL3bc220a5/bridge/inst/doc/bridge.Rnw"
plot(gamma1-gamma2,bridge.hiv$post.p,col=1,pch=1,main="Posterior probability",xlab="log ratio",ylab="posterior probability")


###################################################
### chunk number 6: histdf
###################################################
#line 177 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp7loolu/R.INSTALL3bc220a5/bridge/inst/doc/bridge.Rnw"
hist(bridge.hiv$nu1[3,],main="Posterior degree of freedoms, array 3",xlab="nu",50)


###################################################
### chunk number 7: 
###################################################
#line 200 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp7loolu/R.INSTALL3bc220a5/bridge/inst/doc/bridge.Rnw"
sample1<-matrix(exp(rnorm(150)),50,3)
sample2<-matrix(exp(rnorm(200)),50,4)
sample3<-matrix(exp(rnorm(150)),50,3)

mcmc.bridge3<-bridge.3samples(sample1,sample2,sample3,B=10,min.iter=0,batch=1,mcmc.obj=NULL,all.out=TRUE,verbose=FALSE)
